==> HostCMS-6.1.7.tar: modules/property/i18n/en.php <==
<?php
/**
 * Properties.
 *
 * @package HostCMS 6\Property
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2014 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Properties',
	'title' => 'Additional properties',
	'menu' => 'Property',
	'add' => 'Add',
	'parent_dir' => 'Additional properties',

	'tab_format' => 'Formats',

	'add_title' => 'Add property',
	'edit_title' => 'Edit property',

	'name' => '<acronym title="Name of product property">Name</acronym>',
	'description' => '<acronym title="Property description">Description</acronym>',
	'type' => '<acronym title="Type of product property">Type</acronym>',

	'type0' => 'Integer',
	'type1' => 'String',
	'type2' => 'File',
	'type3' => 'List',
	'type4' => 'Textarea',
	'type5' => 'Information system',
	'type6' => 'Wysiwyg',
	'type7' => 'Checkbox',
	'type8' => 'Date',
	'type9' => 'Date-time',
	'type10' => 'Hidden field',
	'type11' => 'Real number',
	'type12' => 'Shop',

	'list_id' => '<acronym title="Select list of values for property">Lists</acronym>',
	'informationsystem_id' => '<acronym title="Information system sets as a property">Information system</acronym>',
	'shop_id' => '<acronym title="Online store sets as a property">Online store</acronym>',

	'sorting' => '<acronym title="Sorting order">Sorting order</acronym>',
	'default_value' => '<acronym title="Default value of product property">Value</acronym>',
	'tag_name' => '<acronym title="Name of XML tag containing property value">Name of XML tag</acronym>',

	'image_large_max_width' => '<acronym title="Maximum width of large image">Maximum width of large image</acronym>',
	'image_large_max_height' => '<acronym title="Maximum height of large image">Maximum height of large image</acronym>',

	'image_small_max_width' => '<acronym title="Maximum width of small image">Maximum width of small image</acronym>',
	'image_small_max_height' => '<acronym title="Maximum height of small image">Maximum height of small image</acronym>',

	'hide_small_image' => 'Hide small image field',
	'guid' => '<acronym title="Unique identifier in GUID format">GUID</acronym>',
	'id' => 'Id',

	'edit_success' => 'Additional property added successfully.',
	'markDeleted_success' => 'Additional property deleted successfully!',
	'copy_success' => 'Additional property copied successfully.',
	'apply_success' => 'Additional property modified successfully.',

	'type_does_not_exist' => 'Property type %d does not exist.',

	'deletePropertyValue_success' => 'Additional property value deleted successfully.',
	'value_other_owner' => 'Additional property value has differentr owner!',
	'value_not_found' => 'Additional property value not found!',
	'small_file_caption' => 'Small image property "%s"',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeAccess_success' => 'Access have been changed.',

	'allowAccess_success' => 'Access allowed.',
	'denyAccess_success' => 'Access denied',
	'allowAccessChildren_success' => 'Access allowed.',
	'denyAccessChildren_success' => 'Access denied.',
	'multiple' => 'Allow multiple values for property',
);

==> HostCMS-6.8.6.tar: modules/property/i18n/en.php <==
<?php
/**
 * Properties.
 *
 * @package HostCMS
 * @subpackage Property
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Properties',
	'title' => 'Additional properties',
	'menu' => 'Property',
	'add' => 'Add',
	'parent_dir' => 'Additional properties',

	'tab_format' => 'Formats',

	'add_title' => 'Add property',
	'edit_title' => 'Edit property',

	'name' => 'Name',
	'description' => 'Description',
	'type' => 'Type',

	'type0' => 'Integer',
	'type1' => 'String',
	'type2' => 'File',
	'type3' => 'List',
	'type4' => 'Textarea',
	'type5' => 'Information system',
	'type6' => 'Wysiwyg',
	'type7' => 'Checkbox',
	'type8' => 'Date',
	'type9' => 'Date-time',
	'type10' => 'Hidden field',
	'type11' => 'Real number',
	'type12' => 'Shop',

	'list_id' => '<acronym title="Select list of values for property">Lists</acronym>',
	'informationsystem_id' => '<acronym title="Information system sets as a property">Information system</acronym>',
	'shop_id' => '<acronym title="Online store sets as a property">Online store</acronym>',

	'sorting' => 'Sort',
	'default_value' => 'Value',
	'tag_name' => '<acronym title="Name of XML tag containing property value">Name of XML tag</acronym>',

	'image_large_max_width' => 'Maximum width of large image',
	'image_large_max_height' => 'Maximum height of large image',

	'image_small_max_width' => 'Maximum width of small image',
	'image_small_max_height' => 'Maximum height of small image',

	'hide_small_image' => 'Hide small image field',
	'guid' => '<acronym title="Unique identifier in GUID format">GUID</acronym>',
	'id' => 'ID',

	'edit_success' => 'Additional property added successfully.',
	'markDeleted_success' => 'Additional property deleted successfully!',
	'copy_success' => 'Additional property copied successfully.',
	'apply_success' => 'Additional property modified successfully.',

	'type_does_not_exist' => 'Property type %d does not exist.',

	'deletePropertyValue_success' => 'Additional property value deleted successfully.',
	'value_other_owner' => 'Additional property value has differentr owner!',
	'value_not_found' => 'Additional property value not found!',
	'small_file_caption' => 'Small image property "%s"',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeAccess_success' => 'Access have been changed.',

	'allowAccess_success' => 'Access allowed.',
	'denyAccess_success' => 'Access denied',
	'allowAccessChildren_success' => 'Access allowed.',
	'denyAccessChildren_success' => 'Access denied.',
	'multiple' => 'Allow multiple values for property',
	'preserve_aspect_ratio' => 'Preserve aspect ratio',
	'preserve_aspect_ratio_small' => 'Preserve aspect ratio for small images',
	'changeMultiple_success' => 'Multiple have been changed.',
	'watermark_default_use_large_image' => 'Use watermark by default',
	'watermark_default_use_small_image' => 'Use watermark by default for small images',
);
